/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: cfgtabpageuseryn.h 957 2006-02-27 17:51:11Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQOFX_CFGTABPAGEUSER_H
#define AQOFX_CFGTABPAGEUSER_H


#include <qbanking/qbcfgtabpageuser.h>


class CfgTabPageUserYnUi;


class CfgTabPageUserYn: public QBCfgTabPageUser {
private:
  CfgTabPageUserYnUi *_realPage;

public:
  CfgTabPageUserYn(QBanking *qb,
                   AB_USER *u,
                   QWidget *parent=0, const char *name=0, WFlags f=0);
  virtual ~CfgTabPageUserYn();

  virtual bool fromGui();
  virtual bool toGui();
  virtual bool checkGui();
};

#endif // AQDTAUS_CFGTABPAGEUSER_H
